@@ -73,7 +73,7 @@
 //#include "kdebug.h"
 
 extern "C" {
-	KPanelApplet* init( TQWidget* inParent, const TQString& inConfigFile) {
+KDE_EXPORT	KPanelApplet* init( TQWidget* inParent, const TQString& inConfigFile) {
 		TDEGlobal::locale()->insertCatalogue("kima");
 		return new Kima(inConfigFile, KPanelApplet::Normal,
 		                      //KPanelApplet::About | KPanelApplet::Help | KPanelApplet::Preferences,
@@ -430,3 +430,4 @@ void Kima::maybeTip(const TQPoint& inPos){
 	text.append("</table>");
 	tip(rect(), text);
 }
+#include "kima.moc"
